@@ -1,7 +1,7 @@
 package Complete::Util;
 
-our $DATE = '2015-03-30'; # DATE
-our $VERSION = '0.26'; # VERSION
+our $DATE = '2015-04-02'; # DATE
+our $VERSION = '0.27'; # VERSION
 
 use 5.010001;
 use strict;
@@ -246,6 +246,9 @@ sub complete_program {
 $SPEC{complete_file} = {
     v => 1.1,
     summary => 'Complete file and directory from local filesystem',
+    args_groups => [
+        {rel=>'one_of', args=>[qw/filter file_regex_filter/]},
+    ],
     args => {
         word => {
             schema  => [str=>{default=>''}],
@@ -285,6 +288,17 @@ included.
 _
             schema  => ['any*' => {of => ['str*', 'code*']}],
         },
+        file_regex_filter => {
+            summary => 'Filter shortcut for file regex',
+            description => <<'_',
+
+This is a shortcut for constructing a filter. So instead of using `filter`, you
+use this option. This will construct a filter of including only directories or
+regular files, and the file must match a regex pattern. This use-case is common.
+
+_
+            schema => 're*',
+        },
         starting_path => {
             schema  => 'str*',
             default => '.',
@@ -385,6 +399,14 @@ sub complete_file {
             }
             $pass;
         };
+    } elsif (!$filter && $args{file_regex_filter}) {
+        $filter = sub {
+            my $name = shift;
+            return 1 if -d $name;
+            return 0 unless -f _;
+            return 1 if $name =~ $args{file_regex_filter};
+            0;
+        };
     }
 
     Complete::Path::complete_path(
@@ -510,7 +532,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.26 of Complete::Util (from Perl distribution Complete-Util), released on 2015-03-30.
+This document describes version 0.27 of Complete::Util (from Perl distribution Complete-Util), released on 2015-04-02.
 
 =head1 DESCRIPTION
 
@@ -631,6 +653,14 @@ Case-insensitive matching.
 
 =item * B<exp_im_path> => I<bool>
 
+=item * B<file_regex_filter> => I<re>
+
+Filter shortcut for file regex.
+
+This is a shortcut for constructing a filter. So instead of using C<filter>, you
+use this option. This will construct a filter of including only directories or
+regular files, and the file must match a regex pattern. This use-case is common.
+
 =item * B<filter> => I<str|code>
 
 Only return items matching this filter.
@@ -740,7 +770,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete-U
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-SHARYANTO-Complete-Util>.
+Source repository is at L<https://github.com/perlancar/perl-Complete-Util>.
 
 =head1 BUGS
 
